@@ -1,10 +1,10 @@
 from setuptools import setup
 
 setup(
-    name='PGE',
+    name='pygameextra',
     entry_points={
         'console_scripts': [
             'PGE = PGE:PE___entry___PE',
         ],
     }
-)
\ No newline at end of file
+)
